This cli program helps to delete files of format `._<anything>`

### Installation
```bash
pipx install file_remover
```

### Usage
Delete files in current folder recurservely
```bash
remove_files .
```